@@ -372,31 +372,31 @@ void StorageAbout::populateSizes()
                                 m_cancellable));
 
     measure_file(
-                "/home/phablet/anbox-data",
+                g_strconcat(g_get_home_dir(), "/anbox-data", NULL),
                 measure_finished,
                 new MeasureData(running_ptr, this, &m_anboxSize,
                                 m_cancellable));
 
     measure_file(
-                "/home/phablet/.cache/libertine-container",
+                g_strconcat(g_get_user_cache_dir(), "/libertine-container", NULL),
                 measure_finished,
                 new MeasureData(running_ptr, this, &m_libertineSize,
                                 m_cancellable));
 
     measure_file(
-                "/home/phablet/.cache",
+                g_get_user_cache_dir(),
                 measure_finished,
                 new MeasureData(running_ptr, this, &m_appCacheSize,
                                 m_cancellable));
 
     measure_file(
-                "/home/phablet/.config",
+                g_get_user_config_dir(),
                 measure_finished,
                 new MeasureData(running_ptr, this, &m_appConfigSize,
                                 m_cancellable));
 
     measure_file(
-                "/home/phablet/.local/share",
+                g_get_user_data_dir(),
                 measure_finished,
                 new MeasureData(running_ptr, this, &m_appDataSize,
                                 m_cancellable));
