@@ -276,12 +276,14 @@ bool SecurityPrivacy::setPasswordMode(SecurityType type)
        feedback! How hard would it have been to add a bool return? Ah well. */
 
     QString path = "/org/freedesktop/Accounts/User" + QString::number(geteuid());
-    QDBusInterface iface("org.freedesktop.Accounts",
-                         path,
-                         "org.freedesktop.Accounts.User",
-                         QDBusConnection::systemBus());
+    auto callMsg = QDBusMessage::createMethodCall("org.freedesktop.Accounts",
+                                                  path,
+                                                  "org.freedesktop.Accounts.User",
+                                                  "SetPasswordMode");
+    callMsg.setArguments({ newMode, });
+    callMsg.setInteractiveAuthorizationAllowed(true);
 
-    QDBusReply<void> reply = iface.call("SetPasswordMode", newMode);
+    QDBusReply<void> reply = QDBusConnection::systemBus().call(callMsg);
     if (reply.isValid() || reply.error().name() == "org.freedesktop.Accounts.Error.Failed") {
         // We allow "org.freedesktop.Accounts.Error.Failed" because we actually
         // expect that error in some cases.  In Ubuntu Touch, group memberships
